Data documentation compiled by Great Expectations

Documentation autogenerated using Great Expectations.
This is a beta feature! Expect changes in API, behavior, and design.

### Overview

#### Dataset info

Number of variables | 6
Number of observations | ?
Missing cells | ?

#### Variable types

int | 0
float | 0
string | 0
-- | 6

#### Expectation types

- expect_column_to_exist 6
- expect_column_values_to_be_between 1
- expect_column_values_to_match_regex 1
- expect_column_mean_to_be_between 1
- expect_column_values_to_be_in_set 1

### Age (type: --)

#### Statistics

Mean | 30.40

#### Expectation types

- expect_column_to_exist True
- expect_column_mean_to_be_between True
- expect_column_values_to_be_between True

### Name (type: --)

#### Expectation types

- expect_column_to_exist True
- expect_column_values_to_match_regex True

### PClass (type: --)

#### Example values

*

#### Expectation types

- expect_column_to_exist True
- expect_column_values_to_be_in_set False

### Sex (type: --)

#### Expectation types

- expect_column_to_exist True

### SexCode (type: --)

#### Expectation types

- expect_column_to_exist True

### Survived (type: --)

#### Expectation types

- expect_column_to_exist True